@@ -39,16 +39,14 @@ from neutron_lib.api.definitions import extraroute
 from neutron_lib.api.definitions import extraroute_atomic
 from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
+from neutron_lib.api.definitions import fip_pf_description
 from neutron_lib.api.definitions import fip_port_details
-from neutron_lib.api.definitions import firewall
 from neutron_lib.api.definitions import firewall_v2
-from neutron_lib.api.definitions import firewallrouterinsertion
 from neutron_lib.api.definitions import flavors
 from neutron_lib.api.definitions import floating_ip_port_forwarding
 from neutron_lib.api.definitions import floatingip_autodelete_internal
 from neutron_lib.api.definitions import floatingip_pools
 from neutron_lib.api.definitions import flowclassifier
-from neutron_lib.api.definitions import interconnection
 from neutron_lib.api.definitions import ip_allocation
 from neutron_lib.api.definitions import ip_substring_port_filtering
 from neutron_lib.api.definitions import l2_adjacency
@@ -83,9 +81,12 @@ from neutron_lib.api.definitions import qos_bw_limit_direction
 from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import qos_gateway_ip
+from neutron_lib.api.definitions import qos_port_network_policy
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
+from neutron_lib.api.definitions import rbac_address_scope
 from neutron_lib.api.definitions import rbac_security_groups
+from neutron_lib.api.definitions import rbac_subnetpool
 from neutron_lib.api.definitions import revisionifmatch
 from neutron_lib.api.definitions import router_admin_state_down_before_update
 from neutron_lib.api.definitions import router_availability_zone
@@ -99,6 +100,7 @@ from neutron_lib.api.definitions import sfc
 from neutron_lib.api.definitions import sort_key_validation
 from neutron_lib.api.definitions import sorting
 from neutron_lib.api.definitions import standard_attr_segment
+from neutron_lib.api.definitions import stateful_security_group
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_dns_publish_fixed_ip
 from neutron_lib.api.definitions import subnet_onboard
@@ -107,6 +109,7 @@ from neutron_lib.api.definitions import subnet_segmentid_writable
 from neutron_lib.api.definitions import subnet_service_types
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import subnetpool_prefix_ops
+from neutron_lib.api.definitions import tag_ports_during_bulk_creation
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
 from neutron_lib.api.definitions import uplink_status_propagation
@@ -146,15 +149,13 @@ _ALL_API_DEFINITIONS = {
     extraroute_atomic,
     filter_validation,
     fip64,
-    firewall,
     firewall_v2,
-    firewallrouterinsertion,
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
+    fip_pf_description,
     floatingip_autodelete_internal,
     floatingip_pools,
-    interconnection,
     ip_allocation,
     ip_substring_port_filtering,
     l2_adjacency,
@@ -190,9 +191,12 @@ _ALL_API_DEFINITIONS = {
     qos_bw_minimum_ingress,
     qos_default,
     qos_gateway_ip,
+    qos_port_network_policy,
     qos_rule_type_details,
     qos_rules_alias,
+    rbac_address_scope,
     rbac_security_groups,
+    rbac_subnetpool,
     revisionifmatch,
     router_admin_state_down_before_update,
     router_availability_zone,
@@ -206,6 +210,7 @@ _ALL_API_DEFINITIONS = {
     sort_key_validation,
     sorting,
     standard_attr_segment,
+    stateful_security_group,
     subnet,
     subnet_dns_publish_fixed_ip,
     subnet_onboard,
@@ -214,6 +219,7 @@ _ALL_API_DEFINITIONS = {
     subnet_service_types,
     subnetpool,
     subnetpool_prefix_ops,
+    tag_ports_during_bulk_creation,
     trunk,
     trunk_details,
     uplink_status_propagation,
