@@ -42,6 +42,7 @@ KNOWN_ATTRIBUTES = (
     'prefixlen',
     'project_id',
     'qos_policy_id',
+    'service_types',
     constants.SHARED,
     'status',
     'subnets',
@@ -54,7 +55,8 @@ KNOWN_RESOURCES = (
     'ports',
     'routers',
     'subnets',
-    'subnetpools'
+    'subnetpools',
+    'security_groups'
 )
 
 KNOWN_HTTP_ACTIONS = (
@@ -90,18 +92,22 @@ KNOWN_EXTENSIONS = (
     'dns-integration',
     'dvr',
     'empty-string-filtering',
+    'expose-l3-conntrack-helper',
     'expose-port-forwarding-in-fip',
     'ext-gw-mode',
     'external-net',
     'extra_dhcp_opt',
     'extraroute',
+    'extraroute-atomic',
     'filter-validation',
     'fip-port-details',
     'flavors',
     'floating-ip-port-forwarding',
+    'floating-ip-port-forwarding-description',
     'floatingip-autodelete-internal',
     'floatingip-pools',
     'ip-substring-filtering',
+    'l3-conntrack-helper',
     'l3-ha',
     'l3_agent_scheduler',
     'l3-port-ip-change-not-allowed',
@@ -120,10 +126,13 @@ KNOWN_EXTENSIONS = (
     'qos',
     'qos-bw-limit-direction',
     'qos-gateway-ip',
+    'qos-port-network-policy',
     'qos-rules-alias',
     'quotas',
+    'rbac-address-scope',
     'rbac-policies',
     'rbac-security-groups',
+    'rbac-subnetpool',
     'router',
     'router_availability_zone',
     'security-group',
@@ -135,7 +144,9 @@ KNOWN_EXTENSIONS = (
     'standard-attr-revisions',
     'standard-attr-segment',
     'standard-attr-timestamp',
+    'subnet',
     'subnet_allocation',
+    'subnet_dns_publish_fixed_ip',
     'subnet_onboard',
     'subnetpool-prefix-ops',
     'subnet-segmentid-enforce',
@@ -144,27 +155,24 @@ KNOWN_EXTENSIONS = (
     'trunk',
     'trunk-details',
     # Add here list of extensions with pointers to the project repo, e.g.
-    # 'bgp',  # http://git.openstack.org/cgit/openstack/neutron-dynamic-routing
+    # 'bgp',  # https://opendev.org/openstack/neutron-dynamic-routing
 
-    # http://git.openstack.org/cgit/openstack/neutron-fwaas
+    # https://opendev.org/openstack/neutron-fwaas
     'fwaas',
     'fwaasrouterinsertion',
     'fwaas_v2',
-    'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
+    'bgpvpn',  # https://opendev.org/openstack/networking-bgpvpn
     'bgpvpn-routes-control',
     'bgpvpn-vni',
 
-    # git.openstack.org/cgit/openstack/neutron-vpnaas
+    # https://opendev.org/openstack/neutron-vpnaas
     'vpnaas',
     'vpn-endpoint-groups',
     'vpn-flavors',
 
-    # http://git.openstack.org/cgit/openstack/networking-sfc:
+    # https://opendev.org/openstack/networking-sfc:
     'flow_classifier',
     'sfc',
-
-    # http://git.openstack.org/cgit/openstack/neutron-interconnection:
-    'interconnection',
 )
 
 KNOWN_KEYWORDS = (
