@@ -29,24 +29,34 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
+               'is_filter': True,
+               'is_sort_key': True,
                'primary_key': True},
         'name': {'allow_post': True, 'allow_put': True, 'default': '',
                  'validate': {
                      'type:string': db_const.NAME_FIELD_SIZE},
+                 'is_filter': True,
+                 'is_sort_key': True,
                  'is_visible': True},
         'ip_version': {'allow_post': True, 'allow_put': False,
                        'convert_to': converters.convert_to_int,
                        'validate': {'type:values': [4, 6]},
+                       'is_filter': True,
+                       'is_sort_key': True,
                        'is_visible': True},
         'network_id': {'allow_post': True, 'allow_put': False,
                        'required_by_policy': True,
                        'validate': {'type:uuid': None},
+                       'is_filter': True,
+                       'is_sort_key': True,
                        'is_visible': True},
         'subnetpool_id': {'allow_post': True,
                           'allow_put': False,
                           'default': constants.ATTR_NOT_SPECIFIED,
                           'required_by_policy': False,
                           'validate': {'type:subnetpool_id_or_none': None},
+                          'is_filter': True,
+                          'is_sort_key': True,
                           'is_visible': True},
         'prefixlen': {'allow_post': True,
                       'allow_put': False,
@@ -58,17 +68,25 @@ RESOURCE_ATTRIBUTE_MAP = {
         'cidr': {'allow_post': True,
                  'allow_put': False,
                  'default': constants.ATTR_NOT_SPECIFIED,
+                 'convert_to': converters.convert_cidr_to_canonical_format,
                  'validate': {'type:subnet_or_none': None},
                  'required_by_policy': False,
+                 'is_filter': True,
+                 'is_sort_key': True,
                  'is_visible': True},
         'gateway_ip': {'allow_post': True, 'allow_put': True,
                        'default': constants.ATTR_NOT_SPECIFIED,
+                       'convert_to': converters.convert_ip_to_canonical_format,
                        'validate': {'type:ip_address_or_none': None},
+                       'is_filter': True,
+                       'is_sort_key': True,
                        'is_visible': True},
-        'allocation_pools': {'allow_post': True, 'allow_put': True,
-                             'default': constants.ATTR_NOT_SPECIFIED,
-                             'validate': {'type:ip_pools': None},
-                             'is_visible': True},
+        'allocation_pools': {
+            'allow_post': True, 'allow_put': True,
+            'default': constants.ATTR_NOT_SPECIFIED,
+            'convert_to': converters.convert_ip_to_canonical_format,
+            'validate': {'type:ip_pools': None},
+            'is_visible': True},
         'dns_nameservers': {'allow_post': True, 'allow_put': True,
                             'convert_to':
                                 converters.convert_none_to_empty_list,
@@ -85,20 +103,28 @@ RESOURCE_ATTRIBUTE_MAP = {
                       'validate': {
                           'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
+                      'is_filter': True,
+                      'is_sort_key': True,
                       'is_visible': True},
         'enable_dhcp': {'allow_post': True, 'allow_put': True,
                         'default': True,
                         'convert_to': converters.convert_to_boolean,
+                        'is_filter': True,
+                        'is_sort_key': True,
                         'is_visible': True},
         'ipv6_ra_mode': {'allow_post': True, 'allow_put': False,
                          'default': constants.ATTR_NOT_SPECIFIED,
                          'validate': {
                              'type:values': constants.IPV6_MODES},
+                         'is_filter': True,
+                         'is_sort_key': True,
                          'is_visible': True},
         'ipv6_address_mode': {'allow_post': True, 'allow_put': False,
                               'default': constants.ATTR_NOT_SPECIFIED,
                               'validate': {
                                   'type:values': constants.IPV6_MODES},
+                              'is_filter': True,
+                              'is_sort_key': True,
                               'is_visible': True},
         constants.SHARED: {
             'allow_post': False,
@@ -106,6 +132,7 @@ RESOURCE_ATTRIBUTE_MAP = {
             'default': False,
             'convert_to': converters.convert_to_boolean,
             'is_visible': False,
+            'is_filter': True,
             'required_by_policy': True,
             'enforce_policy': True
         }
