@@ -14,8 +14,6 @@
 
 import abc
 
-import six
-
 
 # The following keys are used in the segment dictionaries passed via
 # the driver API.
@@ -33,8 +31,7 @@ BOUND_DRIVER = 'bound_driver'
 BOUND_SEGMENT = 'bound_segment'
 
 
-@six.add_metaclass(abc.ABCMeta)
-class MechanismDriver(object):
+class MechanismDriver(object, metaclass=abc.ABCMeta):
     """Define stable abstract interface for ML2 mechanism drivers.
 
     A mechanism driver is called on the creation, update, and deletion
@@ -55,6 +52,19 @@ class MechanismDriver(object):
     methods that are part of the database transaction.
     """
 
+    # Used in generating resource provider UUIDs for physical network
+    # interfaces. Each mechanism driver supporting Placement should have its
+    # own UUID v5 namespace (which is a UUID v1 in turn). When set to a
+    # concrete value use a uuid.UUID() object, not the string format.
+    # It will be used when hashing RP UUIDs from:
+    #     (mech driver namespace, hostname, physical bridge/interface name)
+    # When needed generate new namespace UUIDs by:
+    #     python -c 'import uuid ; print uuid.uuid1()'
+    # See also:
+    #     https://tools.ietf.org/html/rfc4122
+    #     https://stackoverflow.com/a/7816117
+    resource_provider_uuid5_namespace = None
+
     @abc.abstractmethod
     def initialize(self):
         """Perform driver initialization.
@@ -413,9 +423,40 @@ class MechanismDriver(object):
         """
         return candidate_hosts
 
+    def responsible_for_ports_allocation(self, context):
+        """Is responsible for a port's resource provider?
 
-@six.add_metaclass(abc.ABCMeta)
-class _TypeDriverBase(object):
+        :param context: PortContext instance describing the port
+        :returns: True for responsible, False for not responsible
+
+        For ports having an allocation in Placement (as expressed
+        in the port's binding:profile.allocation) decide while
+        binding if this mechanism driver is responsible for the
+        physical network interface represented by the resource
+        provider in Placement. Find the resource provider UUID in
+        context.current['binding:profile']['allocation'].
+
+        Drivers wanting to support resource allocations for ports in
+        Placement (eg. wanting to guarantee some minimum bandwidth)
+        must implement this method.
+
+        Default implementation returns False (backward compatibility).
+        """
+        return False
+
+    @staticmethod
+    def provider_network_attribute_updates_supported():
+        """Returns the provider network attributes that can be updated
+
+        Possible values: neutron_lib.api.definitions.provider_net.ATTRIBUTES
+
+        :returns: (list) provider network attributes that can be updated in a
+                         live network using this driver.
+        """
+        return []
+
+
+class _TypeDriverBase(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_type(self):
@@ -475,8 +516,7 @@ class _TypeDriverBase(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class TypeDriver(_TypeDriverBase):
+class TypeDriver(_TypeDriverBase, metaclass=abc.ABCMeta):
     """Define abstract interface for ML2 type drivers.
 
     ML2 type drivers each support a specific network_type for provider
@@ -500,11 +540,12 @@ class TypeDriver(_TypeDriverBase):
     """
 
     @abc.abstractmethod
-    def reserve_provider_segment(self, session, segment):
+    def reserve_provider_segment(self, session, segment, filters=None):
         """Reserve resource associated with a provider network segment.
 
         :param session: database session
         :param segment: segment dictionary
+        :param filters: a dictionary that is used as search criteria
         :returns: segment dictionary
 
         Called inside transaction context on session to reserve the
@@ -515,10 +556,11 @@ class TypeDriver(_TypeDriverBase):
         pass
 
     @abc.abstractmethod
-    def allocate_tenant_segment(self, session):
+    def allocate_tenant_segment(self, session, filters=None):
         """Allocate resource for a new tenant network segment.
 
         :param session: database session
+        :param filters: a dictionary that is used as search criteria
         :returns: segment dictionary using keys defined above
 
         Called inside transaction context on session to allocate a new
@@ -545,8 +587,7 @@ class TypeDriver(_TypeDriverBase):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ML2TypeDriver(_TypeDriverBase):
+class ML2TypeDriver(_TypeDriverBase, metaclass=abc.ABCMeta):
     """Define abstract interface for ML2 type drivers.
 
     ML2 type drivers each support a specific network_type for provider
@@ -570,11 +611,12 @@ class ML2TypeDriver(_TypeDriverBase):
     """
 
     @abc.abstractmethod
-    def reserve_provider_segment(self, context, segment):
+    def reserve_provider_segment(self, context, segment, filters=None):
         """Reserve resource associated with a provider network segment.
 
         :param context: instance of neutron context with DB session
         :param segment: segment dictionary
+        :param filters: a dictionary that is used as search criteria
         :returns: segment dictionary
 
         Called inside transaction context on session to reserve the
@@ -585,10 +627,11 @@ class ML2TypeDriver(_TypeDriverBase):
         pass
 
     @abc.abstractmethod
-    def allocate_tenant_segment(self, context):
+    def allocate_tenant_segment(self, context, filters=None):
         """Allocate resource for a new tenant network segment.
 
         :param context: instance of neutron context with DB session
+        :param filters: a dictionary that is used as search criteria
         :returns: segment dictionary using keys defined above
 
         Called inside transaction context on session to allocate a new
@@ -614,9 +657,28 @@ class ML2TypeDriver(_TypeDriverBase):
         """
         pass
 
+    @abc.abstractmethod
+    def initialize_network_segment_range_support(self):
+        """Perform driver network segment range initialization.
 
-@six.add_metaclass(abc.ABCMeta)
-class NetworkContext(object):
+        Called during the initialization of the ``network-segment-range``
+        service plugin if enabled, after all drivers have been loaded and the
+        database has been initialized. This reloads the `default`
+        network segment ranges when Neutron server starts/restarts.
+        """
+        pass
+
+    @abc.abstractmethod
+    def update_network_segment_range_allocations(self):
+        """Update driver network segment range allocations.
+
+        This syncs the driver segment allocations when network segment ranges
+        have been created, updated or deleted.
+        """
+        pass
+
+
+class NetworkContext(object, metaclass=abc.ABCMeta):
     """Context passed to MechanismDrivers for changes to network resources.
 
     A NetworkContext instance wraps a network resource. It provides
@@ -653,8 +715,7 @@ class NetworkContext(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SubnetContext(object):
+class SubnetContext(object, metaclass=abc.ABCMeta):
     """Context passed to MechanismDrivers for changes to subnet resources.
 
     A SubnetContext instance wraps a subnet resource. It provides
@@ -686,8 +747,7 @@ class SubnetContext(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class PortContext(object):
+class PortContext(object, metaclass=abc.ABCMeta):
     """Context passed to MechanismDrivers for changes to port resources.
 
     A PortContext instance wraps a port resource. It provides helper
@@ -1004,8 +1064,7 @@ class PortContext(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ExtensionDriver(object):
+class ExtensionDriver(object, metaclass=abc.ABCMeta):
     """Define stable abstract interface for ML2 extension drivers.
 
     An extension driver extends the core resources implemented by the
