@@ -12,8 +12,8 @@
 #    under the License.
 
 import string
+from unittest import mock
 
-import mock
 import netaddr
 
 from neutron_lib._i18n import _
@@ -149,7 +149,7 @@ class TestAttributeValidation(base.BaseTestCase):
         # Check that value is not comparable to valid_values and got Exception
         data = 1
         valid_values = '[2, 3, 4, 5]'
-        response = "'data' of type '%s' and 'valid_values'of type" \
+        response = "'data' of type '%s' and 'valid_values' of type" \
                    " '%s' are not compatible for comparison" % (
                        type(data), type(valid_values))
         self.assertRaisesRegex(TypeError, response,
@@ -723,6 +723,37 @@ class TestAttributeValidation(base.BaseTestCase):
     def test_validate_subnet(self):
         self._test_validate_subnet(validators.validate_subnet)
 
+    def test_validate_route_cidr(self):
+        # Valid - CIDR
+        cidr = "10.0.0.0/8"
+        msg = validators.validate_route_cidr(cidr, None)
+        self.assertIsNone(msg)
+
+        # Valid - CIDR
+        cidr = "192.168.1.1/32"
+        msg = validators.validate_route_cidr(cidr, None)
+        self.assertIsNone(msg)
+
+        # Invalid - CIDR
+        cidr = "192.168.1.1/8"
+        msg = validators.validate_route_cidr(cidr, None)
+        error = _("'%(data)s' is not a recognized CIDR,"
+                  " '%(cidr)s' is recommended") % {"data": cidr,
+                                                   "cidr": "192.0.0.0/8"}
+        self.assertEqual(error, msg)
+
+        # Invalid - loopback CIDR
+        cidr = "127.0.0.0/8"
+        msg = validators.validate_route_cidr(cidr, None)
+        error = _("'%(data)s' is not a routable CIDR") % {"data": cidr}
+        self.assertEqual(error, msg)
+
+        # Invalid - CIDR format error
+        cidr = 'invalid'
+        msg = validators.validate_route_cidr(cidr, None)
+        error = "'%s' is not a valid CIDR" % cidr
+        self.assertEqual(error, msg)
+
     def test_validate_subnet_or_none(self):
         self._test_validate_subnet(validators.validate_subnet_or_none,
                                    allow_none=True)
@@ -1076,6 +1107,56 @@ class TestAttributeValidation(base.BaseTestCase):
         ]
         self.assertIsNone(validators.validate_subports(body))
 
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_valid_string_new(self, CONF):
+        CONF.sg_filter_ethertypes = True
+        self.assertIsNone(validators.validate_ethertype('IPv4'))
+        self.assertIsNone(validators.validate_ethertype('IPv6'))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_valid_string_old(self, CONF):
+        CONF.sg_filter_ethertypes = False
+        self.assertIsNone(validators.validate_ethertype('IPv4'))
+        self.assertIsNone(validators.validate_ethertype('IPv6'))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_invalid_string(self, CONF):
+        CONF.sg_filter_ethertypes = False
+        self.assertEqual(('Ethertype 0x4008 is not a valid ethertype, must be '
+                          'one of IPv4,IPv6.'),
+                         validators.validate_ethertype('0x4008'))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_extended_valid_string(self, CONF):
+        CONF.sg_filter_ethertypes = True
+        self.assertIsNone(validators.validate_ethertype('0x4008'))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_extended_valid_hexint(self, CONF):
+        CONF.sg_filter_ethertypes = True
+        self.assertIsNone(validators.validate_ethertype(0x4008))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_extended_invalid_negative(self, CONF):
+        CONF.sg_filter_ethertypes = True
+        self.assertEqual(("Ethertype -16392 is not a two octet "
+                          "hexadecimal number or ethertype name."),
+                         validators.validate_ethertype('-0x4008'))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_extended_invalid_nonhex(self, CONF):
+        CONF.sg_filter_ethertypes = True
+        self.assertEqual(("Ethertype invalid is not a two octet "
+                          "hexadecimal number or ethertype name."),
+                         validators.validate_ethertype('invalid'))
+
+    @mock.patch('oslo_config.cfg.CONF')
+    def test_validate_ethertype_extended_invalid_toobig(self, CONF):
+        CONF.sg_filter_ethertypes = True
+        self.assertEqual(("Ethertype 3735928559 is not a two octet "
+                          "hexadecimal number or ethertype name."),
+                         validators.validate_ethertype('0xdeadbeef'))
+
 
 class TestValidateIPSubnetNone(base.BaseTestCase):
 
