@@ -10,7 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+import re
+from unittest import mock
 
 from oslo_config import cfg
 from oslo_db import options
@@ -19,9 +20,10 @@ from oslotest import base
 from neutron_lib.api import attributes
 from neutron_lib.api.definitions import port
 from neutron_lib.callbacks import registry
-from neutron_lib.clients import placement
 from neutron_lib.db import model_base
+from neutron_lib.db import resource_extend
 from neutron_lib import fixture
+from neutron_lib.placement import client as place_client
 from neutron_lib.plugins import directory
 from neutron_lib.tests.unit.api import test_attributes
 
@@ -59,10 +61,12 @@ class SqlFixtureTestCase(base.BaseTestCase):
         options.set_defaults(
             cfg.CONF,
             connection='sqlite://')
-        self.useFixture(fixture.SqlFixture())
+        self.fixture = fixture.StaticSqlFixture()
+        self.useFixture(self.fixture)
 
     def test_fixture(self):
         self.assertIsNotNone(model_base.BASEV2.metadata.sorted_tables)
+        self.assertIsNotNone(self.fixture.engine)
 
 
 class APIDefinitionFixtureTestCase(base.BaseTestCase):
@@ -128,7 +132,7 @@ class APIDefinitionFixtureTestCase(base.BaseTestCase):
 class PlacementAPIClientFixtureTestCase(base.BaseTestCase):
 
     def _create_client_and_fixture(self):
-        placement_client = placement.PlacementAPIClient(mock.Mock())
+        placement_client = place_client.PlacementAPIClient(mock.Mock())
         placement_fixture = self.useFixture(
             fixture.PlacementAPIClientFixture(placement_client))
         return placement_client, placement_fixture
@@ -139,8 +143,10 @@ class PlacementAPIClientFixtureTestCase(base.BaseTestCase):
         p_fixture.mock_post.assert_called_once()
 
     def test_put(self):
+        inventory = {'total': 42}
         p_client, p_fixture = self._create_client_and_fixture()
-        p_client.update_inventory('resource', mock.ANY, 'class_name')
+        p_client.update_resource_provider_inventory('resource', inventory,
+                                                    'class_name', 1)
         p_fixture.mock_put.assert_called_once()
 
     def test_delete(self):
@@ -152,3 +158,42 @@ class PlacementAPIClientFixtureTestCase(base.BaseTestCase):
         p_client, p_fixture = self._create_client_and_fixture()
         p_client.list_aggregates('resource')
         p_fixture.mock_get.assert_called_once()
+
+
+class DBResourceExtendFixtureTestCase(base.BaseTestCase):
+
+    def test_fixture_backup(self):
+        fake_methods = {
+            'a': 'A',
+            'b': 'B'
+        }
+        orig_methods = resource_extend._resource_extend_functions
+        self.assertNotEqual(fake_methods, orig_methods)
+
+        db_fixture = fixture.DBResourceExtendFixture(
+            extended_functions=fake_methods)
+        db_fixture.setUp()
+
+        resource_extend.register_funcs('C', (lambda x: x,))
+        self.assertNotEqual(
+            orig_methods, resource_extend._resource_extend_functions)
+
+        db_fixture.cleanUp()
+        self.assertEqual(
+            orig_methods, resource_extend._resource_extend_functions)
+
+
+class WarningsFixture(base.BaseTestCase):
+
+    @mock.patch.object(fixture.warnings, 'filterwarnings')
+    def test_fixture_regex(self, mock_filterwarnings):
+        module_re = ['^neutron\\.']
+        warn_fixture = fixture.WarningsFixture(module_re=module_re)
+        warn_fixture.setUp()
+        call_re = mock_filterwarnings.mock_calls[0][2]['module']
+        self.assertEqual('^neutron_lib\\.|^neutron\\.', call_re)
+        self.assertIsNotNone(re.compile(call_re))
+        self.assertIsNotNone(re.search(call_re, 'neutron.db.blah'))
+        self.assertIsNotNone(re.search(call_re, 'neutron_lib.db.blah'))
+        self.assertIsNone(re.search(
+            call_re, 'neutron_dynamic_routing.db.blah'))
